@@ -617,7 +617,7 @@ mousepad_history_session_restore (MousepadApplication *application)
               autosave_file = g_file_new_for_uri (autosave_uri);
 
               /* validate file */
-              if (mousepad_util_get_path (autosave_file) == NULL)
+              if (g_file_peek_path (autosave_file) == NULL)
                 {
                   g_warning (CORRUPTED_SESSION_DATA);
                   g_object_unref (autosave_file);
